@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -96,7 +96,7 @@ class ToolbarEnd(Gtk.Bin):
             Notify user about download
             @param download as WebKit2.Download
         """
-        header = Gtk.Label()
+        header = Gtk.Label.new()
         header.set_markup("<b>" + _("Downloading:") + "</b>")
         header.set_ellipsize(Pango.EllipsizeMode.END)
         header.show()
@@ -137,44 +137,34 @@ class ToolbarEnd(Gtk.Bin):
         filechooser.connect("response", self.__on_save_response)
         filechooser.run()
 
-    def save_images(self, uri, page_id):
-        """
-            Show a popover with all images for page id
-            @param uri as str
-            @param page_id as int
-        """
-        from eolie.popover_images import ImagesPopover
-        popover = ImagesPopover(uri, page_id, self.__window)
-        popover.set_relative_to(self.__download_button)
-        popover.popup()
-
-    def save_videos(self, page_id):
-        """
-            Show a popover with videos for page_id
-            @param page_id as int
-        """
-        from eolie.menu_videos import VideosMenu
-        menu = VideosMenu(page_id, self.__window)
-        popover = Gtk.Popover.new_from_model(self.__download_button, menu)
-        popover.set_modal(False)
-        self.__window.register(popover)
-        popover.connect("closed", self.__on_video_menu_popover_closed, menu)
-        popover.popup()
-
     def move_control_in_menu(self, b):
         """
             Move home and download buttons in menu
             @param b as bool
         """
         if b:
-            self.__download_button.hide()
             self.__home_button.hide()
             self.set_hexpand(False)
         else:
-            self.__download_button.show()
             self.__home_button.show()
             self.set_hexpand(True)
 
+    @property
+    def home_button(self):
+        """
+            Get home button
+            @return Gtk.ToogleButton
+        """
+        return self.__home_button
+
+    @property
+    def menu_button(self):
+        """
+            Get download button
+            @return Gtk.ToogleButton
+        """
+        return self.__menu_button
+
     @property
     def download_button(self):
         """
@@ -192,11 +182,11 @@ class ToolbarEnd(Gtk.Bin):
             @param button as Gtk.Button
         """
         self.__window.close_popovers()
-        if not button.get_active():
+        if button == self.__download_button and not button.get_active():
             return
         popover = DownloadsPopover(self.__window)
         # We are relative to toolbar button, button can be in menu
-        popover.set_relative_to(self.__download_button)
+        popover.set_relative_to(button)
         popover.connect("closed", self.__on_popover_closed, button)
         popover.set_modal(False)
         self.__window.register(popover)
@@ -295,15 +285,6 @@ class ToolbarEnd(Gtk.Bin):
             App().update_unity_badge(value)
         return True
 
-    def __on_video_menu_popover_closed(self, popover, model):
-        """
-            Clean menu
-            @param popover as Gtk.Popover
-            @param model as Gio.Menu
-        """
-        # Let model activate actions, idle needed to action activate
-        GLib.idle_add(model.clean)
-
     def __on_save_response(self, dialog, response_id):
         """
             Tell WebKit to save current page
@@ -369,6 +350,10 @@ class ToolbarEnd(Gtk.Bin):
             @param name as str (do not use this)
         """
         if download_manager.active:
+            # Show button if needed
+            if not self.__download_button.is_visible() and\
+                    self.__home_button.is_visible():
+                self.__download_button.show()
             if self.__timeout_id is None:
                 self.__progress.show()
                 self.__timeout_id = GLib.timeout_add(1000,
