@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -10,12 +10,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib, WebKit2
+from gi.repository import GLib, Gio, WebKit2
 
 from urllib.parse import urlparse
 
 from eolie.define import Indicator, App
-from eolie.utils import name_from_profile_id
 
 
 class WebViewLoadSignals:
@@ -108,8 +107,14 @@ class WebViewLoadSignals:
                     popup.destroy()
                 self.__popups = []
             elif event == WebKit2.LoadEvent.FINISHED:
-                self.run_javascript_from_gresource(
-                    "/org/gnome/Eolie/Readability.js", None, None)
+                js1 = Gio.File.new_for_uri(
+                    "resource:///org/gnome/Eolie/Readability.js")
+                js2 = Gio.File.new_for_uri(
+                    "resource:///org/gnome/Eolie/Readability_check.js")
+                (status, content1, tags) = js1.load_contents()
+                (status, content2, tags) = js2.load_contents()
+                script = content1.decode("utf-8") + content2.decode("utf-8")
+                self.run_javascript(script, None, None)
             if webview.get_mapped() and not webview.view.popover:
                 self.__update_toolbars(event)
 
@@ -122,11 +127,11 @@ class WebViewLoadSignals:
             @param event as WebKit2.LoadEvent
         """
         parsed = urlparse(self.uri)
+        self._window.toolbar.title.update()
         wanted_scheme = parsed.scheme in ["http", "https", "file"]
         if event == WebKit2.LoadEvent.STARTED:
             self._window.container.current.find_widget.set_search_mode(False)
-            profile = name_from_profile_id(self.profile)
-            self._window.toolbar.title.set_title(profile, self.uri)
+            self._window.toolbar.title.set_title(self.uri)
             self._window.toolbar.title.show_readable_button(False)
             if wanted_scheme:
                 self._window.toolbar.title.set_loading(True)
@@ -134,13 +139,11 @@ class WebViewLoadSignals:
                 # Give focus to url bar
                 self._window.toolbar.title.start_search()
             self._window.toolbar.title.show_indicator(Indicator.NONE)
-            # Turn off reading mode if needed
-            if self._window.container.current.reading:
-                self._window.container.current.switch_read_mode()
+            # Turn off reading mode
+            self._window.container.current.stop_reading()
             self._window.toolbar.title.progress.show()
         elif event == WebKit2.LoadEvent.COMMITTED:
-            profile = name_from_profile_id(self.profile)
-            self._window.toolbar.title.set_title(profile, self.uri)
+            self._window.toolbar.title.set_title(self.uri)
         elif event == WebKit2.LoadEvent.FINISHED:
             self._window.toolbar.title.set_loading(False)
             self._window.toolbar.title.progress.set_fraction(1.0)
@@ -155,8 +158,7 @@ class WebViewLoadSignals:
             @param title as str
         """
         if webview.get_mapped():
-            profile = name_from_profile_id(self.profile)
-            self._window.toolbar.title.set_title(profile, title)
+            self._window.toolbar.title.set_title(title)
         self._window.container.sites_manager.update_label(self.view)
 
     def __on_uri_changed(self, webview, uri):
@@ -168,7 +170,7 @@ class WebViewLoadSignals:
         if webview.get_mapped():
             accept_tls = App().websettings.get_accept_tls(uri)
             self._window.toolbar.end.show_tls_button(accept_tls)
-            self._window.toolbar.title.set_uri(uri)
+            self._window.toolbar.title.update()
 
     def __on_estimated_load_progress(self, webview, value):
         """
